@@ -57,6 +57,7 @@
 #include <Qt3DRender/qtextureimage.h>
 #include <Qt3DRender/qtexturewrapmode.h>
 #include <Qt3DRender/qwaitfence.h>
+#include <qsharedpointer.h>
 
 namespace Qt3DRender {
     class PropertyReaderInterface;
@@ -136,185 +137,191 @@ namespace Qt3DRender {
 }
 // Type indices
 enum : int {
-    SBK_QT3DRENDER_API_IDX                                   = 3,
-    SBK_Qt3DRenderQT3DRENDER_IDX                             = 2,
-    SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX               = 4,
-    SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                   = 6,
-    SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                        = 5,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX            = 9,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX         = 8,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                    = 7,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 16,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 17,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 18,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX               = 14,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX          = 13,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX   = 11,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX       = 12,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX           = 15,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                      = 10,
-    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 19,
-    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 20,
-    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 22,
-    SBK_QT3DRENDER_QALPHATEST_IDX                            = 21,
-    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 24,
-    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 23,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 26,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 25,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 28,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 27,
-    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 29,
-    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 31,
-    SBK_QT3DRENDER_QCAMERA_IDX                               = 30,
-    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 33,
-    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 32,
-    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 34,
-    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 36,
+    SBK_QT3DRENDER_API_IDX                                   = 4,
+    SBK_Qt3DRenderQT3DRENDER_IDX                             = 3,
+    SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX               = 5,
+    SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                   = 7,
+    SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                        = 6,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX            = 10,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX         = 9,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                    = 8,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 17,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 18,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 19,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX               = 15,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX          = 14,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX   = 12,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX       = 13,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX           = 16,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                      = 11,
+    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 20,
+    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 21,
+    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 23,
+    SBK_QT3DRENDER_QALPHATEST_IDX                            = 22,
+    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 25,
+    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 24,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 27,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 26,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 29,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 28,
+    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 30,
+    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 32,
+    SBK_QT3DRENDER_QCAMERA_IDX                               = 31,
+    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 34,
+    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 33,
+    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 35,
+    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 37,
     SBK_QFLAGS_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX       = 0,
-    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 35,
-    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 37,
-    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 38,
-    SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX               = 40,
-    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 39,
-    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 42,
-    SBK_QT3DRENDER_QCULLFACE_IDX                             = 41,
-    SBK_QT3DRENDER_QDEPTHRANGE_IDX                           = 43,
-    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 45,
-    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 44,
-    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 46,
-    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 47,
-    SBK_QT3DRENDER_QDITHERING_IDX                            = 48,
-    SBK_QT3DRENDER_QEFFECT_IDX                               = 49,
-    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 50,
-    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 51,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 52,
-    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 54,
-    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 53,
-    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 55,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 57,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 56,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 59,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 60,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 58,
-    SBK_QT3DRENDER_QLAYER_IDX                                = 61,
-    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 63,
-    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 62,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 65,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 64,
-    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 66,
-    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 67,
-    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 68,
-    SBK_QT3DRENDER_QMATERIAL_IDX                             = 69,
-    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 71,
+    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 36,
+    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 38,
+    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 39,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX               = 41,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 40,
+    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 43,
+    SBK_QT3DRENDER_QCULLFACE_IDX                             = 42,
+    SBK_QT3DRENDER_QDEPTHRANGE_IDX                           = 44,
+    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 46,
+    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 45,
+    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 47,
+    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 48,
+    SBK_QT3DRENDER_QDITHERING_IDX                            = 49,
+    SBK_QT3DRENDER_QEFFECT_IDX                               = 50,
+    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 51,
+    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 52,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 53,
+    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 55,
+    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 54,
+    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 56,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 58,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 57,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 60,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 61,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 59,
+    SBK_QT3DRENDER_QLAYER_IDX                                = 62,
+    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 64,
+    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 63,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 66,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 65,
+    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 67,
+    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 68,
+    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 69,
+    SBK_QT3DRENDER_QMATERIAL_IDX                             = 70,
+    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 72,
     SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX       = 1,
-    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 70,
-    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 73,
-    SBK_QT3DRENDER_QMESH_IDX                                 = 72,
-    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 74,
-    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 75,
-    SBK_QT3DRENDER_QNODRAW_IDX                               = 76,
-    SBK_QT3DRENDER_QNOPICKING_IDX                            = 77,
-    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 78,
-    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 79,
-    SBK_QT3DRENDER_QPARAMETER_IDX                            = 80,
-    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 82,
-    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 83,
-    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 81,
-    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 84,
-    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 85,
-    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 86,
-    SBK_QT3DRENDER_QPICKINGPROXY_IDX                         = 87,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 90,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 91,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 89,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 88,
-    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 92,
-    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 94,
-    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 93,
-    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 95,
-    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 96,
-    SBK_QT3DRENDER_QRASTERMODE_RASTERMODE_IDX                = 99,
-    SBK_QT3DRENDER_QRASTERMODE_FACEMODE_IDX                  = 98,
-    SBK_QT3DRENDER_QRASTERMODE_IDX                           = 97,
-    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 100,
-    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 102,
-    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 101,
-    SBK_QT3DRENDER_QRENDERASPECT_SUBMISSIONTYPE_IDX          = 104,
-    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 103,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 106,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 107,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 105,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 108,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 109,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 110,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 111,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 113,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 112,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 114,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 115,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 116,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 117,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 119,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 118,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 120,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 123,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 122,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 121,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 124,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 125,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 126,
-    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 128,
-    SBK_QT3DRENDER_QSETFENCE_IDX                             = 127,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 129,
-    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 131,
-    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 132,
-    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 130,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 135,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 136,
-    SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX                 = 134,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 133,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 137,
-    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 138,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 140,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 139,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 141,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 142,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 143,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 145,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 146,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 144,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 147,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 149,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 150,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 148,
-    SBK_QT3DRENDER_QSUBTREEENABLER_ENABLEMENT_IDX            = 152,
-    SBK_QT3DRENDER_QSUBTREEENABLER_IDX                       = 151,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 153,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 154,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 155,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 156,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 157,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 158,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 159,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 160,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 161,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 162,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 163,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 164,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 165,
-    SBK_QT3DRENDER_QTEXTUREDATAUPDATE_IDX                    = 166,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 168,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 167,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 169,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 170,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 171,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 172,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 174,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 173,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 175,
-    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 177,
-    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 176,
-    SBK_Qt3DRender_IDX_COUNT                                 = 178
+    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 71,
+    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 74,
+    SBK_QT3DRENDER_QMESH_IDX                                 = 73,
+    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 75,
+    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 76,
+    SBK_QT3DRENDER_QNODRAW_IDX                               = 77,
+    SBK_QT3DRENDER_QNOPICKING_IDX                            = 78,
+    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 79,
+    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 80,
+    SBK_QT3DRENDER_QPARAMETER_IDX                            = 81,
+    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 83,
+    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 84,
+    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 82,
+    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 85,
+    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 86,
+    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 87,
+    SBK_QT3DRENDER_QPICKINGPROXY_IDX                         = 88,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 91,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 92,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 90,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 89,
+    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 93,
+    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 95,
+    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 94,
+    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 96,
+    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 97,
+    SBK_QT3DRENDER_QRASTERMODE_RASTERMODE_IDX                = 100,
+    SBK_QT3DRENDER_QRASTERMODE_FACEMODE_IDX                  = 99,
+    SBK_QT3DRENDER_QRASTERMODE_IDX                           = 98,
+    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 101,
+    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 103,
+    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 102,
+    SBK_QT3DRENDER_QRENDERASPECT_SUBMISSIONTYPE_IDX          = 105,
+    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 104,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 107,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 108,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 106,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 109,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 110,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 111,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 112,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 114,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 113,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 115,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 116,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 117,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 118,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 120,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 119,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 121,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 124,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 123,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 122,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 125,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 126,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 127,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 129,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 128,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 130,
+    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 132,
+    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 133,
+    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 131,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 136,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 137,
+    SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX                 = 135,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 134,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 138,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 139,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 141,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 140,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 142,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 143,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 144,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 146,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 147,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 145,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 148,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 150,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 151,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 149,
+    SBK_QT3DRENDER_QSUBTREEENABLER_ENABLEMENT_IDX            = 153,
+    SBK_QT3DRENDER_QSUBTREEENABLER_IDX                       = 152,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 154,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 155,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 156,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 157,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 158,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 159,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 160,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 161,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 162,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 163,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 164,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 165,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 166,
+    SBK_QT3DRENDER_QTEXTUREDATAUPDATE_IDX                    = 167,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 169,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 168,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 170,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 171,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 172,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 173,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 175,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 174,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 176,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 178,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 177,
+    SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX      = 179, // QSharedPointer<Qt3DRender::QTextureImageData >
+    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_QTEXTUREIMAGEDATA_IDX = 179, //   (const)
+    SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX = 180, // QSharedPointer<Qt3DRender::QTextureImageDataGenerator >
+    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX = 180, //   (const)
+    SBK_QSHAREDPOINTER_QT3DRENDER_PROPERTYREADERINTERFACE_IDX = 181, // QSharedPointer<Qt3DRender::PropertyReaderInterface >
+    SBK_QSHAREDPOINTER_CONSTQT3DRENDER_PROPERTYREADERINTERFACE_IDX = 181, //   (const)
+    SBK_Qt3DRender_IDX_COUNT                                 = 182
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DRenderTypes;
@@ -328,26 +335,28 @@ extern SbkConverter **SbkPySide6_Qt3DRenderTypeConverters;
 // Converter indices
 enum : int {
     SBK_QT3DRENDER_QLIST_INT_IDX                             = 0, // QList<int >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 1, // QList<Qt3DCore::QNode* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 2, // QList<Qt3DRender::QFilterKey* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 3, // QList<Qt3DRender::QParameter* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 4, // QList<Qt3DRender::QRenderPass* >
-    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 5, // QList<QObject* >
-    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 6, // QList<QByteArray >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 7, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 8, // QList<Qt3DRender::QRenderState* >
-    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 9, // QList<qreal >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 10, // QList<Qt3DRender::QTechnique* >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 11, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 1, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 2, // QList<Qt3DRender::QRayCasterHit >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 3, // QList<Qt3DRender::QLayer* >
+    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 4, // QList<QObject* >
+    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 5, // QList<QByteArray >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 6, // QList<Qt3DRender::QAbstractTextureImage* >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 7, // QList<Qt3DCore::QNode* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 8, // QList<Qt3DRender::QFilterKey* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 9, // QList<Qt3DRender::QParameter* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 10, // QList<Qt3DRender::QRenderState* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 11, // QList<Qt3DRender::QSortPolicy::SortType >
     SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 12, // QList<Qt3DRender::QRenderTargetOutput* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 13, // QList<Qt3DRender::QSortPolicy::SortType >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 14, // QList<Qt3DRender::QLayer* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 15, // QList<Qt3DRender::QAbstractTextureImage* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 16, // QList<Qt3DRender::QRayCasterHit >
-    SBK_QT3DRENDER_QLIST_QVARIANT_IDX                        = 17, // QList<QVariant >
-    SBK_QT3DRENDER_QLIST_QSTRING_IDX                         = 18, // QList<QString >
-    SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX                 = 19, // QMap<QString,QVariant >
-    SBK_Qt3DRender_CONVERTERS_IDX_COUNT                      = 20
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 13, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 14, // QList<Qt3DRender::QTechnique* >
+    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 15, // QList<qreal >
+    SBK_QT3DRENDER_STD_VECTOR_QSHAREDPOINTER_QT3DCORE_QASPECTJOB_IDX = 16, // std::vector<QSharedPointer< Qt3DCore::QAspectJob > >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 17, // QList<Qt3DRender::QRenderPass* >
+    SBK_QT3DRENDER_QLIST_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX = 18, // QList<QSharedPointer< Qt3DRender::QTextureImageData > >
+    SBK_QT3DRENDER_QLIST_QVARIANT_IDX                        = 19, // QList<QVariant >
+    SBK_QT3DRENDER_QLIST_QSTRING_IDX                         = 20, // QList<QString >
+    SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX                 = 21, // QMap<QString,QVariant >
+    SBK_Qt3DRender_CONVERTERS_IDX_COUNT                      = 22
 };
 // Macros for type check
 
@@ -534,6 +543,9 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureWrapMode >() { re
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QViewport >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QVIEWPORT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence::HandleType >() { return SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageData > >() { return SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATA_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::QTextureImageDataGenerator > >() { return SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<Qt3DRender::PropertyReaderInterface > >() { return SbkPySide6_Qt3DRenderTypes[SBK_QSHAREDPOINTER_QT3DRENDER_PROPERTYREADERINTERFACE_IDX]; }
 
 } // namespace Shiboken
 
