@@ -588,37 +588,39 @@ enum : int {
     SBK_QTGUI_QLIST_QSIZE_IDX                                = 20, // QList<QSize >
     SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX                      = 21, // std::pair<qreal,QColor >
     SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 22, // QList<std::pair< qreal,QColor > >
-    SBK_QTGUI_QLIST_UINT16_T_IDX                             = 23, // QList<uint16_t >
-    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 24, // QList<QAccessibleInterface* >
-    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 25, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
-    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 26, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
-    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 27, // QList<unsigned int >
-    SBK_QTGUI_QLIST_QLINE_IDX                                = 28, // QList<QLine >
-    SBK_QTGUI_QLIST_QLINEF_IDX                               = 29, // QList<QLineF >
-    SBK_QTGUI_QLIST_QRECT_IDX                                = 30, // QList<QRect >
-    SBK_QTGUI_QLIST_QRECTF_IDX                               = 31, // QList<QRectF >
-    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 32, // QList<QKeySequence >
-    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 33, // QList<QObject* >
-    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 34, // QList<QByteArray >
-    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 35, // QList<QUndoStack* >
-    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 36, // QList<QTextFrame* >
-    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 37, // QList<QTextBlock >
-    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 38, // QList<QTextFormat >
-    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 39, // QList<QScreen* >
-    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 40, // QList<QOpenGLContext* >
-    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 41, // QSet<QByteArray >
-    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 42, // QList<const QInputDevice* >
-    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 43, // QList<QAction* >
-    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 44, // QList<QInputMethodEvent::Attribute >
-    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 45, // QList<QEventPoint >
-    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 46, // QList<QWindow* >
-    SBK_QTGUI_QLIST_QMODELINDEX_IDX                          = 47, // QList<QModelIndex >
-    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 48, // QList<QPersistentModelIndex >
-    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 49, // QHash<int,QByteArray >
-    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 50, // QList<QVariant >
-    SBK_QTGUI_QLIST_QSTRING_IDX                              = 51, // QList<QString >
-    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 52, // QMap<QString,QVariant >
-    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 53
+    SBK_QTGUI_QLIST_QSIZETYPE_IDX                            = 23, // QList<qsizetype >
+    SBK_QTGUI_QLIST_UINT16_T_IDX                             = 24, // QList<uint16_t >
+    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 25, // QList<QAccessibleInterface* >
+    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 26, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
+    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 27, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
+    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 28, // QList<unsigned int >
+    SBK_QTGUI_QLIST_QLINE_IDX                                = 29, // QList<QLine >
+    SBK_QTGUI_QLIST_QLINEF_IDX                               = 30, // QList<QLineF >
+    SBK_QTGUI_QLIST_QRECT_IDX                                = 31, // QList<QRect >
+    SBK_QTGUI_QLIST_QRECTF_IDX                               = 32, // QList<QRectF >
+    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 33, // QList<QKeySequence >
+    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 34, // QList<QObject* >
+    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 35, // QList<QByteArray >
+    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 36, // QList<QUndoStack* >
+    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 37, // QList<QTextFrame* >
+    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 38, // QList<QTextBlock >
+    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 39, // QList<QTextFormat >
+    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 40, // QList<QScreen* >
+    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 41, // QList<QOpenGLContext* >
+    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 42, // QSet<QByteArray >
+    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 43, // QList<const QInputDevice* >
+    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 44, // QList<QAction* >
+    SBK_QTGUI_QLIST_QABSTRACTTEXTDOCUMENTLAYOUT_SELECTION_IDX = 45, // QList<QAbstractTextDocumentLayout::Selection >
+    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 46, // QList<QInputMethodEvent::Attribute >
+    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 47, // QList<QEventPoint >
+    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 48, // QList<QWindow* >
+    SBK_QTGUI_QLIST_QMODELINDEX_IDX                          = 49, // QList<QModelIndex >
+    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 50, // QList<QPersistentModelIndex >
+    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 51, // QHash<int,QByteArray >
+    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 52, // QList<QVariant >
+    SBK_QTGUI_QLIST_QSTRING_IDX                              = 53, // QList<QString >
+    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 54, // QMap<QString,QVariant >
+    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 55
 };
 // Macros for type check
 
