@@ -28,6 +28,7 @@
 #include <QtQml/qqmlfile.h>
 #include <QtQml/qqmlincubator.h>
 #include <QtQml/qqmlproperty.h>
+#include <QtQml/qqmlscriptstring.h>
 class QJSValueIterator;
 class QPyQmlParserStatus;
 class QPyQmlPropertyValueSource;
@@ -44,7 +45,6 @@ class QQmlNetworkAccessManagerFactory;
 class QQmlParserStatus;
 class QQmlPropertyMap;
 class QQmlPropertyValueSource;
-class QQmlScriptString;
 class QQmlTypesExtensionInterface;
 // Begin code injection
 // Volatile Bool Ptr type definition for QQmlIncubationController::incubateWhile(std::atomic<bool> *, int)
