@@ -20,7 +20,9 @@
 // Bound library includes
 #include <QtQuick/qquickframebufferobject.h>
 #include <QtQuick/qquickitem.h>
+#include <QtQuick/qquickitemgrabresult.h>
 #include <QtQuick/qquickpainteditem.h>
+#include <QtQuick/qquicktextdocument.h>
 #include <QtQuick/qquickview.h>
 #include <QtQuick/qquickwindow.h>
 #include <QtQuick/qsggeometry.h>
@@ -37,12 +39,9 @@ class QQuickGraphicsConfiguration;
 class QQuickGraphicsDevice;
 class QQuickImageProvider;
 class QQuickImageResponse;
-class QQuickItemGrabResult;
 class QQuickRenderControl;
 class QQuickRenderTarget;
-class QQuickTextDocument;
 class QQuickTextureFactory;
-class QQuickTransform;
 class QSGBasicGeometryNode;
 class QSGClipNode;
 class QSGDynamicTexture;
@@ -169,14 +168,15 @@ extern SbkConverter **SbkPySide6_QtQuickTypeConverters;
 // Converter indices
 enum : int {
     SBK_QTQUICK_QLIST_INT_IDX                                = 0, // QList<int >
-    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 1, // QList<QByteArray >
-    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 2, // QList<QObject* >
-    SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 3, // QList<QQuickItem* >
-    SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 4, // QList<QQmlError >
-    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // QMap<QString,QVariant >
-    SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 6, // QList<QVariant >
-    SBK_QTQUICK_QLIST_QSTRING_IDX                            = 7, // QList<QString >
-    SBK_QtQuick_CONVERTERS_IDX_COUNT                         = 8
+    SBK_QTQUICK_QLIST_QSGGEOMETRY_POINT2D_IDX                = 1, // QList<QSGGeometry::Point2D >
+    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 2, // QList<QByteArray >
+    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 3, // QList<QObject* >
+    SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 4, // QList<QQuickItem* >
+    SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 5, // QList<QQmlError >
+    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 6, // QMap<QString,QVariant >
+    SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 7, // QList<QVariant >
+    SBK_QTQUICK_QLIST_QSTRING_IDX                            = 8, // QList<QString >
+    SBK_QtQuick_CONVERTERS_IDX_COUNT                         = 9
 };
 // Macros for type check
 
